==> drools-pmml-6.2.0.CR2-sources.jar: java/org/dmg/pmml/pmml_4_2/descr/TargetValueStat.java <==

package org.dmg.pmml.pmml_4_2.descr;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;group ref="{http://www.dmg.org/PMML-4_2}CONTINUOUS-DISTRIBUTION-TYPES"/>
 *       &lt;/sequence>
 *       &lt;attribute name="value" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensionsAndAnyDistributionsAndGaussianDistributions"
})
@XmlRootElement(name = "TargetValueStat")
public class TargetValueStat
    implements Serializable
{

    private final static long serialVersionUID = 145235L;
    @XmlElements({
        @XmlElement(name = "UniformDistribution", type = UniformDistribution.class),
        @XmlElement(name = "PoissonDistribution", type = PoissonDistribution.class),
        @XmlElement(name = "Extension", type = Extension.class),
        @XmlElement(name = "GaussianDistribution", type = GaussianDistribution.class),
        @XmlElement(name = "AnyDistribution", type = AnyDistribution.class)
    })
    protected List<Serializable> extensionsAndAnyDistributionsAndGaussianDistributions;
    @XmlAttribute(name = "value", required = true)
    protected String value;

    /**
     * Gets the value of the extensionsAndAnyDistributionsAndGaussianDistributions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensionsAndAnyDistributionsAndGaussianDistributions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensionsAndAnyDistributionsAndGaussianDistributions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link UniformDistribution }
     * {@link PoissonDistribution }
     * {@link Extension }
     * {@link GaussianDistribution }
     * {@link AnyDistribution }
     * 
     * 
     */
    public List<Serializable> getExtensionsAndAnyDistributionsAndGaussianDistributions() {
        if (extensionsAndAnyDistributionsAndGaussianDistributions == null) {
            extensionsAndAnyDistributionsAndGaussianDistributions = new ArrayList<Serializable>();
        }
        return this.extensionsAndAnyDistributionsAndGaussianDistributions;
    }

    /**
     * Gets the value of the value property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getValue() {
        return value;
    }

    /**
     * Sets the value of the value property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setValue(String value) {
        this.value = value;
    }

}

==> drools-pmml-6.3.0.CR2-sources.jar: java/org/dmg/pmml/pmml_4_2/descr/TargetValueStat.java <==

package org.dmg.pmml.pmml_4_2.descr;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;group ref="{http://www.dmg.org/PMML-4_2}CONTINUOUS-DISTRIBUTION-TYPES"/>
 *       &lt;/sequence>
 *       &lt;attribute name="value" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensionsAndAnyDistributionsAndGaussianDistributions"
})
@XmlRootElement(name = "TargetValueStat")
public class TargetValueStat
    implements Serializable
{

    private final static long serialVersionUID = 145235L;
    @XmlElements({
        @XmlElement(name = "AnyDistribution", type = AnyDistribution.class),
        @XmlElement(name = "UniformDistribution", type = UniformDistribution.class),
        @XmlElement(name = "GaussianDistribution", type = GaussianDistribution.class),
        @XmlElement(name = "PoissonDistribution", type = PoissonDistribution.class),
        @XmlElement(name = "Extension", type = Extension.class)
    })
    protected List<Serializable> extensionsAndAnyDistributionsAndGaussianDistributions;
    @XmlAttribute(name = "value", required = true)
    protected String value;

    /**
     * Gets the value of the extensionsAndAnyDistributionsAndGaussianDistributions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensionsAndAnyDistributionsAndGaussianDistributions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensionsAndAnyDistributionsAndGaussianDistributions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link AnyDistribution }
     * {@link UniformDistribution }
     * {@link GaussianDistribution }
     * {@link PoissonDistribution }
     * {@link Extension }
     * 
     * 
     */
    public List<Serializable> getExtensionsAndAnyDistributionsAndGaussianDistributions() {
        if (extensionsAndAnyDistributionsAndGaussianDistributions == null) {
            extensionsAndAnyDistributionsAndGaussianDistributions = new ArrayList<Serializable>();
        }
        return this.extensionsAndAnyDistributionsAndGaussianDistributions;
    }

    /**
     * Gets the value of the value property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getValue() {
        return value;
    }

    /**
     * Sets the value of the value property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setValue(String value) {
        this.value = value;
    }

}
